@@ -15,7 +15,7 @@ Dancer2::Plugin::Database - easy database connections for Dancer2 applications
 
 =cut
 
-our $VERSION = '2.14';
+our $VERSION = '2.16';
 
 register_hook qw(database_connected
                  database_connection_lost
@@ -27,7 +27,16 @@ my $settings = {};
 
 sub _load_settings {
     my $dsl = shift;
-    $settings = plugin_setting();
+    # ugly plugin1/2 switch - to be removed one day
+    if ( $dsl->app->can('with_plugin') ) {
+        # plugin2
+        # We need this for plugins which use this plugins
+        $settings = $dsl->config;
+    }
+    else {
+        # plugin1
+        $settings = plugin_setting();
+    }
     $settings->{charset} ||= $dsl->setting('charset') || 'utf-8';
 }
 
@@ -279,39 +288,14 @@ You can also pass a hashref of settings if you wish to provide settings at
 runtime.
 
 
-=head1 CONVENIENCE FEATURES (quick_select, quick_update, quick_insert, quick_delete, quick_count)
+=head1 CONVENIENCE FEATURES
 
 The handle returned by the C<database> keyword is a
 L<Dancer::Plugin::Database::Core::Handle> object, which subclasses the C<DBI::db> DBI
 connection handle.  This means you can use it just like you'd normally use a DBI
-handle, but extra convenience methods are provided, as documented in the POD for
-L<Dancer::Plugin::Database::Core::Handle>.
+handle, but extra convenience methods are provided.
 
-Examples:
-
-  # Quickly fetch the (first) row whose ID is 42 as a hashref:
-  my $row = database->quick_select($table_name, { id => 42 });
-
-  # Fetch all badgers as an array of hashrefs:
-  my @badgers = database->quick_select('animals', { genus => 'Mellivora' });
-
-  # Update the row where the 'id' column is '42', setting the 'foo' column to
-  # 'Bar':
-  database->quick_update($table_name, { id => 42 }, { foo => 'Bar' });
-
-  # Insert a new row, using a named connection (see above)
-  database('connectionname')->quick_insert($table_name, { foo => 'Bar' });
-
-  # Delete the row with id 42:
-  database->quick_delete($table_name, { id => 42 });
-
-  # Fetch all rows from a table (since version 1.30):
-  database->quick_select($table_name, {});
-
-  # Retrieve a count of rows matching the criteria:
-  database->quick_count($table_name, {});
-
-There's more extensive documentation on these features in
+There's extensive documentation on these features in
 L<Dancer::Plugin::Database::Core::Handle>, including using the C<order_by>, C<limit>,
 C<columns> options to sort / limit results and include only specific columns.
 
@@ -460,7 +444,7 @@ You can find the author on IRC in the channel C<#dancer> on <irc.perl.org>.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010-13 David Precious.
+Copyright 2010-2016 David Precious.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
